@@ -414,7 +414,7 @@ eog_scroll_view_set_cursor (EogScrollView *view, EogScrollViewCursor new_cursor)
 	if (cursor) {
 		gdk_window_set_cursor (gtk_widget_get_window (widget), cursor);
 		g_object_unref (cursor);
-		gdk_flush();
+		gdk_display_flush(display);
 	}
 }
 
